package com.pms.ocp.controller;

import com.pms.ocp.biz.BizModelRequirementInfoService;
import com.pms.ocp.model.dto.ModelPropertyVersionRequirementDTO;
import com.pms.ocp.model.dto.ModelVersionRequirementDTO;
import com.pms.ocp.model.vo.ResponseVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @Auther: wangjian
 * @Date: 2022/3/29 17:18
 * @Description:模型库管理管控需求接口
 */

@Slf4j
@RequestMapping("/model-control/v1")
@RestController
@Api(tags = "模型库管理管控需求接口")
public class ModelControlDemandController {

    @Autowired
    private BizModelRequirementInfoService bizModelRequirementInfoService;

    /**
     * 模型需求-增加
     *
     * @return
     */
    @ApiOperation("模型需求-增加")
    @PostMapping("/create/modelDemand")
    public ResponseVO createModelDemand(@RequestBody ModelVersionRequirementDTO modelVersionRequirementDTO) {

        return ResponseVO.ok(bizModelRequirementInfoService.createModelRequirementInfo(modelVersionRequirementDTO));
    }

    /**
     * 模型属性需求-增加
     *
     * @return
     */
    @ApiOperation("模型属性需求-增加")
    @PostMapping("/create/modelPropertyDemand")
    public ResponseVO createModelPropertyDemand(@RequestBody ModelPropertyVersionRequirementDTO modelPropertyVersionRequirementDTO) {

        return ResponseVO.ok(bizModelRequirementInfoService.createModelPropertyRequirementInfo(modelPropertyVersionRequirementDTO));
    }

    /**
     * 模型需求-删除
     *
     * @return
     */
    @ApiOperation("模型需求-删除")
    @PostMapping("/delete/modelDemand")
    public ResponseVO deleteModelDemand(@ApiParam(value = "模型订阅编号") @RequestParam(value = "objId", required = false) String objId,
                                        @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode) {
        return ResponseVO.ok(bizModelRequirementInfoService.deleteModelRequirementInfo(objId, modelCode));
    }

    /**
     * 模型属性需求-删除
     *
     * @return
     */
    @ApiOperation("模型属性需求-删除")
    @PostMapping("/delete/modelPropertyDemand")
    public ResponseVO deleteModelPropertyDemand(@ApiParam(value = "模型订阅编号") @RequestParam(value = "objId", required = false) String objId,
                                                @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode,
                                                @ApiParam(value = "属性编码") @RequestParam(value = "propCode", required = false) String propCode) {
        return ResponseVO.ok(bizModelRequirementInfoService.deleteModelPropertyRequirementInfo(objId, modelCode, propCode));
    }

    /**
     * 模型需求-修改
     *
     * @return
     */
    @ApiOperation("模型需求-修改")
    @PostMapping("/update/modelDemand")
    public ResponseVO updateModelDemand(@RequestBody ModelVersionRequirementDTO modelVersionRequirementDTO) {
        return ResponseVO.ok(bizModelRequirementInfoService.updateModelRequirementInfo(modelVersionRequirementDTO));
    }

    /**
     * 模型属性需求-修改
     *
     * @return
     */
    @ApiOperation("模型属性需求-修改")
    @PostMapping("/update/modelPropertyDemand")
    public ResponseVO updateModelPropertyDemand(@RequestBody ModelPropertyVersionRequirementDTO modelPropertyVersionRequirementDTO) {
        return ResponseVO.ok(bizModelRequirementInfoService.updateModelPropertyRequirementInfo(modelPropertyVersionRequirementDTO));
    }

    /**
     * 模型需求-查询列表
     *
     * @return
     */
    @ApiOperation("模型需求-查询列表")
    @GetMapping("/get/modelDemand/list")
    public ResponseVO getModelDemandList(
            @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode,
            @ApiParam(value = "模型名称") @RequestParam(value = "modelName", required = false) String modelName,
            @ApiParam(value = "模型分类编码") @RequestParam(value = "modelGroupCode", required = false) String modelGroupCode,
            @ApiParam(value = "当前页") @RequestParam(value = "currentPage") Integer currentPage,
            @ApiParam(value = "每页数量") @RequestParam(value = "pageSize") Integer pageSize) {
        return ResponseVO.ok(bizModelRequirementInfoService.getModelRequirementInfoList(modelName, modelCode, modelGroupCode, currentPage, pageSize));

    }

    /**
     * 模型属性需求-查询列表
     *
     * @return
     */
    @ApiOperation("模型属性需求-查询列表")
    @GetMapping("/get/modelPropertyDemand/list")
    public ResponseVO getModelPropertyDemandList(@ApiParam(value = "需求编码") @RequestParam(value = "requirementCode", required = false) String requirementCode,
                                                 @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode,
                                                 @ApiParam(value = "当前页") @RequestParam(value = "currentPage") Integer currentPage,
                                                 @ApiParam(value = "每页数量") @RequestParam(value = "pageSize") Integer pageSize) {
        return ResponseVO.ok(bizModelRequirementInfoService.getModelPropertyRequirementInfoList(requirementCode, modelCode, currentPage, pageSize));

    }


}
